# -*- coding: utf-8 -*-

from markdownprocessor import CodeBlockPreprocessor

import markdown

class Processor(object):
    """This class is the one responsible for processing the posts sources
    and generate the resulting HTML code.
    """

    def process(self, post):
        """This method is responsible of processing the post's markup into HTML.

        It must be redefined for the different markups that are going to be supported.
        The resulting HTML *must* be stored in post['html']

        If this Processor is used, the content is returned as is.

        :param post: the dict with the post to process
        :returns: dict
        """
        return post

class MarkdownProcessor(Processor):
    """The markdown syntax processor for oak posts.

    """

    def process(self, post):
        """The process method for Markdown posts.

        """
        if post.get('raw'):
            md = markdown.Markdown()
            md.preprocessors.insert(0, 'text', CodeBlockPreprocessor())
            post['html'] = md.convert(post.get('raw'))
        return post




# -*- coding: utf-8 -*-
"""
.. module:: oak
    :platform: Unix
    :synopsys: A static blog generator

.. moduleauthor:: Marcos <marc0s@fsfe.org>

"""

import codecs
import glob
import os
import shutil
import sys

from jinja2 import Environment, FileSystemLoader

from oak.models.post import Post
from oak.models.tag import Tag
from oak.utils import copytree_, Filters, Atom
from oak.processors import processor

class Oak(object):
    """The main Oak class

    """

    logger = None
    settings = None
    posts = []
    authors = {}
    tags = {}

    def __init__(self, logger=None, settings=None):
        """Initializes the class

        The logger and the settings module are stored and the Jinja environment
        set up.

        :param logger: The logger object
        :param settings: The settings module to be used along the generation process
        :type settings: module
        """

        if logger:
            self.logger = logger
        if settings:
            self.settings = settings

        self.logger.info("Starting up...")
        # set up the Jinja environment
        # get the filters
        self.jenv = Environment(loader=FileSystemLoader(os.path.sep.join([self.settings.LAYOUTS_PATH, self.settings.DEFAULT_LAYOUT])))
        self.jenv.filters['datetimeformat'] = Filters.datetimeformat
        self.jenv.filters['longdate'] = Filters.longdate
        self.jenv.filters['shortdate'] = Filters.shortdate
        self.jenv.filters['isodate'] = Filters.isodate
        self.logger.debug("Template environment ready.")
        self.tpl_vars = {
            'blog': {
                'title': self.settings.BLOG_TITLE,
                'url': self.settings.BLOG_URL,
                'id': "%s%s%s" % (self.settings.BLOG_URL, os.path.sep, "atom.xml"),
                'last_updated': None, # Will be updated when reading posts.
                'author': self.settings.AUTHOR,
                'email': self.settings.EMAIL,
            },
            'license_text': self.settings.BLOG_LICENSE_TEXT,
            'links': {
                'site': self.settings.PREFIX or '/', # if there is no prefix, use /
                'taglist': os.path.sep.join([self.settings.PREFIX, self.settings.HTMLS['taglist']]),
                'archive': os.path.sep.join([self.settings.PREFIX, self.settings.HTMLS['archive']]),
                'authors': os.path.sep.join([self.settings.PREFIX, self.settings.HTMLS['authors']]),
                'feed': os.path.sep.join([self.settings.BLOG_URL, self.settings.HTMLS['feed']]),
            }
        }


    def _post_path(self, filename):
        """Calculates the final path for a post given a filename
        
        :param filename: the name of the input file
        :type filename: string

        :returns: string
        """
        self.logger.debug("_post_path:%s" % (filename,))
        year, month = filename.split('-')[:2]
        newfilename = "%s.html" % (os.path.splitext(filename)[0],)
        self.logger.debug("_post_path:%s" % (newfilename,))
        return os.path.sep.join([self.settings.OUTPUT_PATH, year, month, newfilename])

    def _tag_path(self, tagname=None):
        """Calculates the final path for a tag page given a tag name

        :param tagname: the name of the tag. If None, return just the directory where tag files are write to
        :type tagname: string

        :returns: string
        """
        if tagname:
            return os.path.sep.join([self.settings.OUTPUT_PATH, self.settings.TAGS_PREFIX, "%s.html" % (tagname,)])
        return os.path.sep.join([self.settings.OUTPUT_PATH, self.settings.TAGS_PREFIX])
    
    def _post_url(self, filename):
        """Calculates the URL of a post given a filename

        :param filename: the name of the output (generated) file
        :type filename: string

        :return: string
        """
        year, month = filename.split('-')[:2]
        newfilename = "%s.html" % (os.path.splitext(filename)[0],)
        return os.path.sep.join([self.settings.PREFIX, year, month, newfilename])

    def _tag_url(self, tagname):
        """Calculates the URL for a tag page given a tag name

        :param tagname: the name of the tag
        :type tagname: string

        :return: string
        """
        return os.path.sep.join([self.settings.PREFIX, self.settings.TAGS_PREFIX, "%s.html" % (tagname,)])

    def _index_path(self):
        """Calculates the path of the index page

        :return: string
        """
        return os.path.sep.join([self.settings.OUTPUT_PATH, self.settings.HTMLS['index']])

    def _index_url(self):
        """Calculates the URL for the index page

        :returns: string
        """
        return os.path.sep.join([self.settings.PREFIX, self.settings.HTMLS['index']])

    def _tag_index_url(self):
        """Calculates the URL for the tags index page

        :returns: string
        """
        return os.path.sep.join([self.settings.PREFIX, self.settings.HTMLS['taglist']])

    def _tag_index_path(self):
        """Calculates the PATH for the tags index page

        :returns: string
        """
        return os.path.sep.join([self.settings.OUTPUT_PATH, self.settings.HTMLS['taglist']])

    def _feed_path(self):
        """Calculates the PATH for the atom.xml feed

        :returns: string
        """
        return os.path.sep.join([self.settings.OUTPUT_PATH, 'atom.xml'])

    def _write_file(self, filename, content):
        """Writes content in filename.

        :param filename: the output file name
        :type filename: string

        :param content: the content to write
        :type content: string

        """
        self.logger.debug("Writing to file '%s'" % (filename,))
        if filename.count(os.path.sep): # if it's a path, check for directories
            if not os.path.exists(os.path.dirname(filename)):
                os.makedirs(os.path.dirname(filename))
        outfile = codecs.open(filename, mode='w', encoding='utf-8')
        outfile.write(content)
        outfile.close()

    def _copy_statics(self):
        """Copies the satic files to the output static path.

        """
        static_path = os.path.sep.join([self.settings.OUTPUT_PATH, self.settings.STATIC_PATH])
        self.logger.debug("Using '%s' as static_path" % (static_path),)
        copytree_(self.settings.STATIC_PATH, static_path)
        tpl_static = os.path.sep.join([self.settings.LAYOUTS_PATH, self.settings.DEFAULT_LAYOUT, self.settings.STATIC_PATH])
        self.logger.debug("Using '%s' as template static path" % (tpl_static),)
        if os.path.exists(tpl_static) and os.path.isdir(tpl_static):
            copytree_(tpl_static, static_path)

    def _do_posts(self):
        """Do the posts generation.
        """
        self.logger.info("Rendering posts...")
        self.logger.info("Using %s as source of content." % (self.settings.CONTENT_PATH,))
        for f in glob.glob("%s/*.%s" % (self.settings.CONTENT_PATH,self.settings.SRC_EXT)):
            filename = os.path.basename(f)
            # TODO add sanity check on source filename (count of - ...)
            post_path = os.path.sep.join([self.settings.CONTENT_PATH] + filename.split('-')[:2])
            newfilename = "%s.html" % (os.path.splitext(filename)[0],)
            self.logger.info("Processing %s..." % (filename,))
            post = Post(f, self.settings.POST_DEFAULTS, processor.MarkdownProcessor)
            post['url'] = "%s%s" % (self.settings.BLOG_URL, self._post_url(newfilename))
            post['id'] = Atom.gen_id(post)
            self.posts.append(post)
            # cache the tags of the current post
            for t in post['metadata']['tags']:
                if t not in self.tags.keys():
                    self.tags[t] = Tag(tag=t, url=self._tag_url(t), posts=[post])
                else:
                    self.tags[t]['posts'].append(post)
            # cache the author of the current post
            author = post['metadata']['author']
            if author not in self.authors.keys():
                self.authors[author] = [post]
            else:
                self.authors[author].append(post)

            # make sure we have the final path created
            if not os.path.exists(post_path) or not os.path.isdir(post_path):
                self.logger.debug("Output directory %s not found, creating" % (post_path,))
                os.makedirs(post_path)
            self.tpl_vars.update({'post': post})
            self.logger.debug("tpl_vars: %s" % (self.tpl_vars,))
            output = self.jenv.get_template(self.settings.TEMPLATES['post']).render(self.tpl_vars)
            self.logger.info("Generating output file in %s" % (self._post_path(filename),))
            self._write_file(self._post_path(filename), output)
            self.tpl_vars.pop('post') # remove the aded key

    def _do_tag(self, tag):
        """Create the page for the tag 'tag'
        """
        self.tpl_vars.update({'tag': tag})
        output = self.jenv.get_template(self.settings.TEMPLATES['tag']).render(self.tpl_vars)
        self.logger.info("Generating tag page for %s in %s" % (tag['tag'], self._tag_path(tag['tag'])))
        self._write_file(self._tag_path(tag['tag']), output)
        # remove added keys
        self.tpl_vars.pop('tag') 

    def _do_tags(self):
        """Do the tags index page
        """
        if not os.path.exists(self._tag_path()) or not os.path.isdir(self._tag_path()):
            self.logger.debug("Tag files directory %s not found, creating" % (self._tag_path(),))
            os.makedirs(self._tag_path())
        self.tpl_vars.update({'tags': self.tags})
        output = self.jenv.get_template(self.settings.TEMPLATES['taglist']).render(self.tpl_vars)
        self._write_file(self._tag_index_path(), output)
        self.tpl_vars.pop('tags')
        for t in self.tags.keys():
            self._do_tag(self.tags[t])

    def _do_index(self):
        # ------ POSTS INDEX ------
        # let's sort the posts in chronological order
        self.posts.sort(lambda x, y: cmp(x['metadata']['pub_date'], y['metadata']['pub_date']))
        # Update the blog.last_updated key for self.tpl_vars
        self.tpl_vars['blog']['last_updated'] = self.posts[0]['metadata']['pub_date']
        if self.settings.POSTS_SORT_REVERSE:
            self.posts.reverse()
        self.tpl_vars.update({'posts': self.posts[:self.settings.POSTS_COUNT]})
        self.logger.info("Generating index page at %s" % (self._index_path(),))
        output = self.jenv.get_template(self.settings.TEMPLATES['index']).render(self.tpl_vars)
        self._write_file(self._index_path(), output)
        self.tpl_vars.pop('posts')

    def _do_feed(self):
        """Generates an Atom feed of the blog posts

        """
        self.tpl_vars.update({'posts': self.posts})
        self.logger.info("Generating atom.xml at %s" % (self._feed_path(),))
        output = self.jenv.get_template(self.settings.TEMPLATES['feed']).render(self.tpl_vars)
        self._write_file(self._feed_path(), output)
        self.tpl_vars.pop('posts')
        self.logger.info("atom.xml file generated.")

    def generate(self):
        """Generates the HTML files to be published.

        :raises: MarkupError, RenderError
        """
        self.logger.info("Using '%s' as layout path." % (self.settings.DEFAULT_LAYOUT,))

        self._do_posts()
        self._do_tags()
        self._copy_statics()
        self._do_index()
        # the feed MUST be done after the index
        if self.settings.GENERATE_FEED:
            self._do_feed()




# -*- coding: utf-8 -*-

import sys
import os
import logging

from optparse import OptionParser, OptionGroup

import oak

class Launcher(object):
    "The entrypoint for command line calls"

    LOG_LEVELS = {
        'debug': logging.DEBUG,
        'info': logging.INFO,
        'warning': logging.WARNING,
        'error': logging.ERROR,
        'critical': logging.CRITICAL
    }

    logger = None
    settings = None

    def __init__(self, settings=None):
        self.settings = settings

    def setup_logging(self, loglevel='warning'):
        self.logger = logging.getLogger('oak')
        ch = logging.StreamHandler(sys.stdout)
        formatter = logging.Formatter("%(asctime)s:%(name)s:%(levelname)s:%(message)s")
        ch.setFormatter(formatter)
        ch.setLevel(self.LOG_LEVELS[loglevel])
        self.logger.addHandler(ch)
        self.logger.setLevel(self.LOG_LEVELS[loglevel])

    def get_logger(self, loglevel='warning'):
        if not self.logger:
            self.logger = self.setup_logging(loglevel=loglevel)
        return self.logger
        
    def run(self, argv=None):
        parser = OptionParser(usage="%prog [OPTIONS]", version="%prog 0.1")
        parser.add_option("-g", "--generate", action="store_true", dest="generate", default=False, help = "Generate the source for your site.")
        parser.add_option("--loglevel", dest="loglevel", default="warning", help="Set the log output level")

        group = OptionGroup(parser, "Output options (overriding settings.py)")
        group.add_option("-l", "--layout", dest="layout", default=self.settings.DEFAULT_LAYOUT, help="Set the layout to use")
        group.add_option("-d", "--destination", dest="destination", default=self.settings.OUTPUT_PATH, help="Set the destination of the output")
        parser.add_option_group(group)

        (options, args) = parser.parse_args()
        print(options.loglevel)

        self.setup_logging(loglevel=options.loglevel)

        if options.generate:
            # override settings with commandline options
            if options.layout:
                self.settings.DEFAULT_LAYOUT=options.layout
            if options.destination:
                self.settings.OUTPUT_PATH=options.destination
            # set the path to the layouts directory
            self.settings.LAYOUTS_PATH = os.path.sep.join([os.path.dirname(oak.__file__), self.settings.LAYOUTS_PATH])
            self.logger.debug("LAYOUTS_PATH set to %s" % (self.settings.LAYOUTS_PATH,))
            self.logger.info("Settings loaded.")
            # instantiate Oak with the given settings
            my_oak = oak.Oak(logger=self.logger, settings=self.settings)
            self.logger.info("Oak initiated.")
            # call the generation process
            my_oak.generate()
            self.logger.info("Geneartion completed.")
        else:
            parser.print_help()




# -*- coding: utf-8 -*-
"Helper functions for oak"

import datetime
import hashlib
import os
import shutil
import time

def copytree_(src, dst):
    names = os.listdir(src)
    if not os.path.exists(dst):
        os.mkdir(dst)
    for name in names:
        srcname = os.path.join(src, name)
        dstname = os.path.join(dst, name)
        try:
            if os.path.isdir(srcname):
                copytree_(srcname, dstname)
            else:
                shutil.copy2(srcname, dstname)
        except (IOError, os.error), why:
            raise Exception(why)
    try:
        shutil.copystat(src, dst)
    except OSError, why:
        raise Exception(why)

class Filters:
    @staticmethod
    def datetimeformat(value, oformat='%Y-%m-%d', iformat="%Y-%m-%d %H:%M:%S"):
        return time.strftime(oformat, time.strptime(str(value), iformat))

    @staticmethod
    def my_date(value=None, oformat='a', iformat='%Y-%m-%d %H:%M:%S'):
        """
            oformat values:
            'a': Dow, month dom, year
            'b': month dom, year
        """
        days = {
            0: ['Mon', 'Monday'],
            1: ['Tue', 'Tuesday'],
            2: ['Wed', 'Wednesday'],
            3: ['Thu', 'Thursday'],
            4: ['Fri', 'Friday'],
            5: ['Sat', 'Saturday'],
            6: ['Sun', 'Sunday'],
        }
        months = {
            1: ['Jan', 'January'],
            2: ['Feb', 'February'],
            3: ['Mar', 'March'],
            4: ['Apr', 'April'],
            5: ['May', 'May'],
            6: ['Jun', 'June'],
            7: ['Jul', 'July'],
            8: ['Aug', 'August'],
            9: ['Sep', 'September'],
            10: ['Oct', 'October'],
            11: ['Nov', 'November'],
            12: ['Dec', 'December'],
        }
        d = time.strptime(str(value), iformat)
        if oformat == 'a':
            return "%s, %s %s, %s" % (days[d.tm_wday][1], months[d.tm_mon][1], d.tm_mday, d.tm_year)
        if oformat == 'b':
            return "%s %s, %s" % (months[d.tm_mon][0], d.tm_mday, d.tm_year)
        if oformat == 'c':
            return datetime.datetime.fromtimestamp(time.mktime(d)).isoformat()

    @staticmethod
    def longdate(value):
        return Filters.my_date(value, 'a')

    @staticmethod 
    def shortdate(value):
        return Filters.my_date(value, 'b')

    @staticmethod
    def isodate(value):
        return Filters.my_date(value, 'c')

class Atom(object):
    """Class for Atom-related stuff.
    """

    @staticmethod
    def gen_id(post):
        """Generates the atom:id for the post `post`

        :param string: the post object
        :returns: string
        """
        import urlparse
        u = urlparse.urlsplit(post['url'])
        d = post['metadata']['pub_date']
        d = Filters.datetimeformat(d)
        _id = "tag:%s,%s:%s" % (u.hostname, d, u.path)
        return _id




# -*- coding: utf-8 -*-

# Settings file for oak

# Set the default author name for the blog
AUTHOR = 'your name will be fine'
EMAIL = 'your email' # not required

# Set the blog title
BLOG_TITLE = 'your blog title'

# Set the URL of your blog, only used when generating the Atom feed.
BLOG_URL = 'http://example.com'

# The blog's contents license, you can include HTML
BLOG_LICENSE_TEXT = 'The contents of this site are put on the <a href="http://creativecommons.org/publicdomain/zero/1.0/">public domain</a>'

# URL prefixes
# Put / if your blog will be in http://example.com/ or /blog if it will be in http://example.com/blog and so on
PREFIX = ''
ARCHIVE_PREFIX = 'archive'
TAGS_PREFIX = 'tag'

# Set the path to the directory where the contents will be created
CONTENT_PATH = 'content'

# Set the extension that the sources will have
SRC_EXT = 'md'

# Set the format of the post file name, now posts MUST have the format below!
# UNUSED, changing it has no effect!!
POST_FILE_FORMAT = "%Y-%m-%s.html"

# Set the path to the static content directory, it will be copied as-is to OUTPUT_PATH/static
# It will serve as the name for layout-relative static files (i.e.: layouts/foo/static)
STATIC_PATH = 'static'

# Set the path where the output will be generated
OUTPUT_PATH = 'site'

# Set the path to the layouts directory, the default is OK if you are using the installed oak package
# You'll probably don't want to change it unless you know what you're doing
LAYOUTS_PATH = 'layouts'

# Set the name of the default layout
DEFAULT_LAYOUT = 'default'

# Set how many posts will be shown in the frontpage, set it to None to show them all
POSTS_COUNT = 10

# By default, posts are sort from older to newer, set to True to invert this behaviour (newer first)
POSTS_SORT_REVERSE = True

# The names of the templates
TEMPLATES = {
    '*': 'base.jinja', # for unknown page types
    'index': 'index.jinja', # the template will receive a list with the last N links to individual pages
    'archive': 'archive.jinja', # the template will receive a full list of individual pages
    'post': 'post.jinja', # the template will receive ...
    'taglist': 'tags.jinja', # the template will receive a list of tags
    'tag': 'tag.jinja', # the template for one tag
    'feed': 'atom.jinja', # the template for the atom feed
}

HTMLS = {
    'index': 'index.html',
    'taglist': 'tags.html',
    'archive': 'archive.html',
    'authors': 'authors.html',
    'feed': 'atom.xml',
}

# Wether to generate a 'tags' index page or not (True or False)
# Still not used, tag page is always generated
GENERATE_TAGS = True

# Wether to generate an 'atom.xml' feed or not (True or False)
GENERATE_FEED = True

# This is a dict with the default options for posts, which can be overriden
# by setting the keys on the YAML header in the post .md file
POST_DEFAULTS = {
    'title': 'Post title',
    'author': AUTHOR,
    'layout': 'post',
    'tags': [],
}





# -*- coding: utf-8 -*-
"""Oak manager

This class provides the utils to manage the initialization
of new oak projects.

It's pretended to be called from oak-admin.py:

$ oak-admin.py --init <foo>

Its main function is to create the <foo> directory for holding
the blog and copying the default settings.py and other stuff to
the project directory.

"""

import os
import shutil

from optparse import OptionParser

import oak

class Manager(object):
    def __init__(self):
        pass

    def init(self, path):
        """This method creates the needed directories and the settings
        module to be customized as well as the manage.py launcher."""
        # check the path does not already exists
        if os.path.exists(path):
            raise Exception("Refusing to overwrite an existing path.")
        
        # create the base project path and other dirs
        os.makedirs(path)
        # TODO use default settings
        os.makedirs(os.path.sep.join([path, 'content'])) # where content is created
        os.makedirs(os.path.sep.join([path, 'site'])) # where blog is generated
        os.makedirs(os.path.sep.join([path, 'static'])) # where static files are

        # obtain where the oak module is located and copy settings.py and manage.py
        oak_path = os.path.dirname(oak.__file__)
        shutil.copy2(os.path.sep.join([oak_path, 'settings.py']), path)
        shutil.copy2(os.path.sep.join([oak_path, 'scripts', 'manage.py']), path)
        print("""
        You may now want to edit your %s/settings.py file and initialize the git
        repository on %s.
        """ % (path, path))

    def run(self, argv):
        parser = OptionParser(usage="%prog [OPTIONS]", version="%prog 0.1")
        parser.add_option("-i", "--init", dest="init", default=None, help="Initialize project")
        (options, args) = parser.parse_args()

        if options.init:
            path = os.path.abspath(options.init)
            self.init(path=path)





# -*- coding: utf-8 -*-

import yaml
import codecs

import oak.processors as procs

HEADER_MARK = '---'

class PostError(Exception):
    """Custom exception for invalid posts."""
    def __init__(self, msg):
        self.msg = msg


class Post(dict):
    """
    A class to hold the contents of a post file.
    A post file is a text file which must contain a YAML header
    defining its metadata, and it must be the first content
    of the file, for example:

    ---
      title: 'post title'
      author: 'post author name'
      pub_date: '2010-05-02 17:00:00'
      tags: ['tag1','tag2',...]
    ---
    
    Post title
    ==========

    This is a sample post.

    Other dashes --- may appear here, obviously.


    As seen in the example, three dashes (---) determines the
    header start and end.

    """
    def __init__(self, f, metadata, processor=None):
        """The Post class __init__

        :param f: the path to the post file
        :param metadata: default metadata dict
        :param processor: the processor to render post's contents
        :processor type: class

        :raises: PostError
        """
        try:
            _f = codecs.open(f, mode='r', encoding='utf-8')
        except:
            raise PostError('Unable to open file. Hint: isn\'t it UTF-8 encoded?')
        
        # Set metadata to the app defaults
        self['metadata'] = metadata.copy()
        self.f = _f.read()
        if not self.f.startswith(HEADER_MARK):
            raise PostError('Post file invalid, no header found.')
        _, metadata, self['raw'] = self.f.split(HEADER_MARK, 2)
        # update the metadata with the header's contents
        self['metadata'].update(yaml.load(metadata))
        # TODO auto determine processor based on metadata['markup']
        if processor:
            p = processor()
            self = p.process(self)




# -*- coding: utf-8 -*-
"""
    The Pygments Markdown Preprocessor
    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

    This fragment is a Markdown_ preprocessor that renders source code
    to HTML via Pygments.  To use it, invoke Markdown like so::

        from markdown import Markdown

        md = Markdown()
        md.preprocessors.insert(0, CodeBlockPreprocessor())
        markdown = md.__str__

    markdown is then a callable that can be passed to the context of
    a template and used in that template, for example.

    This uses CSS classes by default, so use
    ``pygmentize -S <some style> -f html > pygments.css``
    to create a stylesheet to be added to the website.

    You can then highlight source code in your markdown markup::

        [sourcecode:lexer]
        some code
        [/sourcecode]

    .. _Markdown: http://www.freewisdom.org/projects/python-markdown/

    :copyright: 2007 by Jochen Kupperschmidt.
    :license: BSD, see LICENSE for more details.
"""

# Options
# ~~~~~~~

# Set to True if you want inline CSS styles instead of classes
INLINESTYLES = True


import re

from markdown.preprocessors import Preprocessor

from pygments import highlight
from pygments.formatters import HtmlFormatter
from pygments.lexers import get_lexer_by_name, TextLexer


class CodeBlockPreprocessor(Preprocessor):

    pattern = re.compile(
        r'\[sourcecode:(.+?)\](.+?)\[/sourcecode\]', re.S)


    def run(self, lines):
        def repl(m):
            try:
                lexer = get_lexer_by_name(m.group(1))
            except ValueError:
                lexer = TextLexer()
            formatter = HtmlFormatter(noclasses=INLINESTYLES)
            code = highlight(m.group(2), lexer, formatter)
            code = code.replace('\n\n', '\n&nbsp;\n')
            return '\n\n<div class="code">%s</div>\n\n' % code
        return self.pattern.sub(
            repl, '\n'.join(lines)).split('\n')



#!/usr/bin/env python

import sys
from oak.launcher import Launcher

try:
    import settings
except ImportError:
    print("No settings found. Have you run oak-admin.py --init?")
    sys.exit(1)

if __name__ == '__main__':
    launcher = Launcher(settings=settings)
    launcher.run(sys.argv[1:])




# -*- coding: utf-8 -*-
import os
from distutils.core import setup

def find_templates():
    _paths = []
    for r, d, f in os.walk('oak/layouts'):
        if len(f):
            for _f in f:
                _paths.append(r.strip('oak/') + '/' + _f)
    return _paths


setup(
    name='Oak',
    version='0.1.4',
    url='http://github.com/marc0s/oak',
    author='marc0s',
    author_email='marc0s@fsfe.org',
    packages=['oak', 'oak.models', 'oak.processors', 'oak.utils'],
    package_data={'oak': ['scripts/manage.py', ] + find_templates() },
    scripts=['bin/oak-admin.py',],
    requires=['Jinja2','Markdown','PyYAML','Pygments'],
    license='WTFPL',
    long_description=open('README.md').read(),
)

